@@ -197,13 +197,17 @@ message_info_from_db (CamelFolderSummary *s,
 		gchar **values;
 
 		iinfo = (CamelEwsMessageInfo *) info;
-		values = g_strsplit (part, " ", -1);
+		if (part) {
+			values = g_strsplit (part, " ", -1);
 
-		iinfo->server_flags = g_ascii_strtoll (values[0], NULL, 10);
-		iinfo->item_type = g_ascii_strtoll (values[1], NULL, 10);
-		iinfo->change_key = g_strdup (values[2]);
+			if (values && values[0] && values[1] && values[2]) {
+				iinfo->server_flags = g_ascii_strtoll (values[0], NULL, 10);
+				iinfo->item_type = g_ascii_strtoll (values[1], NULL, 10);
+				iinfo->change_key = g_strdup (values[2]);
+			}
 
-		g_strfreev (values);
+			g_strfreev (values);
+		}
 	}
 
 	return info;
@@ -303,23 +307,6 @@ camel_ews_summary_add_message (CamelFolderSummary *summary,
 	camel_message_info_free (info);
 }
 
-void
-camel_ews_summary_add_message_info (CamelFolderSummary *summary,
-                                    guint32 server_flags,
-                                    CamelMessageInfo *mi)
-{
-	CamelMessageInfoBase *binfo = (CamelMessageInfoBase *) mi;
-	CamelEwsMessageInfo *einfo = (CamelEwsMessageInfo *) mi;
-
-	binfo->flags |= server_flags;
-	einfo->server_flags = server_flags;
-
-	/* TODO update user flags */
-
-	binfo->flags &= ~CAMEL_MESSAGE_FOLDER_FLAGGED;
-	camel_folder_summary_add (summary, (CamelMessageInfo *) mi);
-}
-
 static gboolean
 ews_update_user_flags (CamelMessageInfo *info,
                        CamelFlag *server_user_flags)
