@@ -141,12 +141,10 @@ mail_config_ews_oal_combo_box_try_password_sync (ESourceAuthenticator *auth,
 	EMailConfigServiceBackend *backend;
 	CamelSettings *settings;
 	CamelEwsSettings *ews_settings;
-	CamelNetworkSettings *network_settings;
 	ESourceAuthenticationResult result;
 	EEwsConnection *cnc;
 	GSList *oal_items = NULL;
 	const gchar *oab_url;
-	const gchar *user;
 	GError *local_error = NULL;
 
 	combo_box = E_MAIL_CONFIG_EWS_OAL_COMBO_BOX (auth);
@@ -156,15 +154,8 @@ mail_config_ews_oal_combo_box_try_password_sync (ESourceAuthenticator *auth,
 	ews_settings = CAMEL_EWS_SETTINGS (settings);
 	oab_url = camel_ews_settings_get_oaburl (ews_settings);
 
-	network_settings = CAMEL_NETWORK_SETTINGS (settings);
-	user = camel_network_settings_get_user (network_settings);
-
-	/* XXX This takes a GError but never fails, so skip it. */
-	cnc = e_ews_connection_new (
-		oab_url, user, password->str,
-		camel_network_settings_get_auth_mechanism (network_settings),
-		camel_ews_settings_get_timeout (ews_settings),
-		NULL, NULL, NULL);
+	cnc = e_ews_connection_new (oab_url, ews_settings);
+	e_ews_connection_set_password (cnc, password->str);
 
 	e_ews_connection_get_oal_list_sync (
 		cnc, &oal_items, cancellable, &local_error);
@@ -331,6 +322,7 @@ e_mail_config_ews_oal_combo_box_update_finish (EMailConfigEwsOalComboBox *combo_
 	GSimpleAsyncResult *simple;
 	GtkComboBoxText *combo_box_text;
 	GSList *list, *link;
+	gchar *active_id;
 
 	g_return_val_if_fail (
 		g_simple_async_result_is_valid (
@@ -349,19 +341,28 @@ e_mail_config_ews_oal_combo_box_update_finish (EMailConfigEwsOalComboBox *combo_
 	combo_box->priv->oal_items = NULL;
 	g_mutex_unlock (combo_box->priv->oal_items_lock);
 
+	active_id = g_strdup (gtk_combo_box_get_active_id (GTK_COMBO_BOX (combo_box)));
 	combo_box_text = GTK_COMBO_BOX_TEXT (combo_box);
 	gtk_combo_box_text_remove_all (combo_box_text);
 
 	for (link = list; link != NULL; link = g_slist_next (link)) {
 		EwsOAL *oal = link->data;
+		const gchar *name = oal->name;
+
+		while (name && *name == '\\')
+			name++;
 
 		gtk_combo_box_text_append (
-			combo_box_text, oal->id, oal->name);
+			combo_box_text, oal->id, name);
 	}
 
 	g_slist_free_full (list, (GDestroyNotify) ews_oal_free);
 
-	gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), 0);
+	if (active_id && *active_id)
+		gtk_combo_box_set_active_id (GTK_COMBO_BOX (combo_box), active_id);
+	else
+		gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), 0);
+	g_free (active_id);
 
 	return TRUE;
 }
