@@ -45,8 +45,9 @@ resolve_names_cb (GObject *object,
 	gboolean has_last_item = FALSE;
 	GError *error = NULL;
 
-	e_ews_connection_resolve_names_finish	(cnc, res, &mailboxes, &contact_items,
-						 &has_last_item, &error);
+	e_ews_connection_resolve_names_finish (
+		cnc, res, &mailboxes, &contact_items,
+		&has_last_item, &error);
 	if (error != NULL) {
 		g_warning ("Unable to autocomplete: %s \n", error->message);
 		g_clear_error (&error);
@@ -80,6 +81,7 @@ op_test_resolve_names ()
 	const gchar *uri;
 	EEwsConnection *cnc;
 	GCancellable *cancellable;
+	CamelEwsSettings *settings;
 
 	cancellable = g_cancellable_new ();
 
@@ -88,8 +90,15 @@ op_test_resolve_names ()
 	g_assert_cmpstr (password, !=, NULL);
 	g_assert_cmpstr (uri, !=, NULL);
 
-	cnc = e_ews_connection_new (uri, username, password, NULL, 30, NULL, NULL, NULL);
-	g_assert (cnc != NULL);
+	settings = g_object_new (
+		CAMEL_TYPE_EWS_SETTINGS,
+		"user", username, NULL);
+
+	cnc = e_ews_connection_new (uri, settings);
+	e_ews_connection_set_password (cnc, password);
+
+	g_object_unref (settings);
+
 	e_ews_connection_resolve_names (
 		cnc, EWS_PRIORITY_MEDIUM, username,
 		EWS_SEARCH_AD, NULL, FALSE, cancellable,
