@@ -44,8 +44,9 @@ get_oof_settings_cb (GObject *object,
 	OOFSettings *oof_settings;
 	GError *error = NULL;
 
-	e_ews_connection_get_oof_settings_finish (cnc, res, &oof_settings,
-						  &error);
+	e_ews_connection_get_oof_settings_finish (
+		cnc, res, &oof_settings,
+		&error);
 	if (error != NULL) {
 		g_warning ("Unable to get out of office settings: %s \n", error->message);
 		g_clear_error (&error);
@@ -66,6 +67,7 @@ op_test_get_oof_settings ()
 	const gchar *uri, *email;
 	EEwsConnection *cnc;
 	GCancellable *cancellable;
+	CamelEwsSettings *settings;
 
 	cancellable = g_cancellable_new ();
 
@@ -77,8 +79,14 @@ op_test_get_oof_settings ()
 	g_assert_cmpstr (uri, !=, NULL);
 	g_assert_cmpstr (email, !=, NULL);
 
-	cnc = e_ews_connection_new (uri, username, password, NULL, 30, NULL, NULL, NULL);
-	g_assert (cnc != NULL);
+	settings = g_object_new (
+		CAMEL_TYPE_EWS_SETTINGS,
+		"username", username, NULL);
+
+	cnc = e_ews_connection_new (uri, settings);
+	e_ews_connection_set_password (cnc, password);
+
+	g_object_unref (settings);
 
 	e_ews_connection_set_mailbox (cnc, email);
 
